Installation
============

cxroots uses the Python_ programming language and is compatible with both Python 2 and 3.

With Python installed the easiest way to install cxroots, along with its dependencies, is using the Python Package Index (PyPi) by running on the command line::

	pip install cxroots
